==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/af/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Bates toegewys aan: naam',
    'bulk_update_warn'	=> 'Jy is op die punt om die eienskappe van gebruikers_count gebruikers te wysig. Hou daar rekening mee dat u nie u eie gebruikers eienskappe kan verander deur hierdie vorm te gebruik en u eie gebruikers afzonderlijk moet wysig.',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie gebruikers gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'current_assets'    => 'Bates wat tans na hierdie gebruiker gekontroleer word',
    'clone'             => 'Klone gebruiker',
    'contact_user'      => 'Kontak naam',
    'edit'              => 'Wysig gebruiker',
    'filetype_info'     => 'Toegelate filetipes is png, gif, jpg, jpeg, doc, docx, pdf, txt, zip en rar.',
    'history_user'      => 'Geskiedenis vir: naam',
	'info'				=> 'info',
    'restore_user'		=> 'Klik hier om dit te herstel.',
    'last_login'        => 'Laaste Aanmelding',
    'ldap_config_text'  => 'LDAP-konfigurasie-instellings kan Admin> Instellings gevind word. Die (opsionele) gekose ligging sal vir alle ingevoerde gebruikers gestel word.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Sagteware Uitgesoek na: naam',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Sien gebruiker: naam',
    'usercsv'           => 'CSV-lêer',
    'two_factor_admin_optin_help' => 'Jou huidige administrasie-instellings laat selektiewe handhawing van twee-faktor-verifikasie toe.',
    'two_factor_enrolled' => '2FA-toestel ingeskryf',
    'two_factor_active'   => '2FA aktief',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/af/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Bates toegewys aan: naam',
    'bulk_update_warn'	=> 'Jy is op die punt om die eienskappe van gebruikers_count gebruikers te wysig. Hou daar rekening mee dat u nie u eie gebruikers eienskappe kan verander deur hierdie vorm te gebruik en u eie gebruikers afzonderlijk moet wysig.',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie gebruikers gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'current_assets'    => 'Bates wat tans na hierdie gebruiker gekontroleer word',
    'clone'             => 'Klone gebruiker',
    'contact_user'      => 'Kontak naam',
    'edit'              => 'Wysig gebruiker',
    'filetype_info'     => 'Toegelate filetipes is png, gif, jpg, jpeg, doc, docx, pdf, txt, zip en rar.',
    'history_user'      => 'Geskiedenis vir: naam',
    'info'				=> 'info',
    'restore_user'		=> 'Klik hier om dit te herstel.',
    'last_login'        => 'Laaste Aanmelding',
    'ldap_config_text'  => 'LDAP-konfigurasie-instellings kan Admin> Instellings gevind word. Die (opsionele) gekose ligging sal vir alle ingevoerde gebruikers gestel word.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Sagteware Uitgesoek na: naam',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Sien gebruiker: naam',
    'usercsv'           => 'CSV-lêer',
    'two_factor_admin_optin_help' => 'Jou huidige administrasie-instellings laat selektiewe handhawing van twee-faktor-verifikasie toe.',
    'two_factor_enrolled' => '2FA-toestel ingeskryf',
    'two_factor_active'   => '2FA aktief',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
